Welcome to PiWorld! (current version 0.1.0)

PiWorld is a small python library (mainly intended as a personal project) which houses a couple pi related commands

Here, pi is stored as a string as an alternative to floating-point limits (where pi's value is only accurate up to the 15th decimal)

The library currently has 5 commands which are:
============
`pi10` -> returns pi up to the 10th decimal
`pi20` -> returns pi up to the 20th decimal
`pi50` -> returns pi up to the 50th decimal
`pi100` -> returns pi up to the 100th decimal
`pi200` -> returns pi up to the 200th decimal
============
(More coming soon)

PiWorld GitHub repo: TBA

PLEASE NOTE:
------------
This is not meant to be a fully practical library with groundbreaking use, 
it is simply a fun little project serving as my own introduction to PyPI and GitHub.
This project might be getting some sparse updates here and there, but nothing major.

Contact: TBA

~ Seif